@@ -88,7 +88,8 @@ SimExtract <- function(object, what, fuzzy = TRUE, append = TRUE){
     stopifnot(is(object, "SimDesign"))
     what <- tolower(what)
     pick <- attr(object, 'design_names')$design
-    Design <- if(any(pick != 'dummy_run'))
+    Design <- if(any(pick != 'dummy_run') &&
+                 all(attr(object, 'design_names')$design %in% names(object)))
         object[,attr(object, 'design_names')$design]
         else dplyr::tibble(.rows = nrow(object))
     if(what == 'design') return(Design)
@@ -115,7 +116,10 @@ SimExtract <- function(object, what, fuzzy = TRUE, append = TRUE){
         attr(object, 'extra_info')$save_info['save_results_dirname']
     } else if(what == 'filename'){
         attr(object, 'extra_info')$save_info['filename']
-    } else stop('Input provided to \"what" is not supported')
+    } else if(what == 'design.id'){
+        attr(object, 'extra_info')$Design.ID
+    }
+    else stop('Input provided to \"what" is not supported')
     ret
 }
 
