@@ -103,9 +103,9 @@ test_that('SimDesign', {
     set.seed(1234)
     res <- SimSolve(condition, b=.80, interval=c(.1, 3), integer=FALSE,
                     generate=mysim_md, analyse=mycompute, summarise=mycollect,
-                    maxiter=30, verbose=FALSE)
+                    maxiter=40, verbose=FALSE)
     expect_is(res, 'SimSolve')
-    expect_equal(res$mean_diff, 1.321, tol=1e-3)
+    expect_equal(res$mean_diff, 1.326, tol=1e-3)
 
     # test that future package works
     suppressPackageStartupMessages(suppressWarnings(library(future)))
@@ -708,11 +708,14 @@ test_that('SimDesign', {
     Design3 <- createDesign(N = c(40, 50),
                             SD = c(1, 2, 3))
 
-    bDesign <- rbind(Design, Design2, Design3)
+    bDesign <- rbindDesign(Design, Design2, Design3)
     expect_equal(attr(bDesign, 'Design.ID'), 1:nrow(bDesign))
 
-    bDesign <- rbind(Design3, Design2, Design)
+    bDesign <- rbindDesign(Design3, Design2, Design)
     expect_equal(attr(bDesign, 'Design.ID'), 1:nrow(bDesign))
 
+    bDesign <- rbindDesign(Design3, Design2, Design, keep.IDs=TRUE)
+    expect_equal(attr(bDesign, 'Design.ID'), c(1:6, 1:3, 1:6))
+
 })
 
